@@ -519,6 +519,7 @@ namespace kt
 		show_kt_action->setShortcut(show_kt_action->globalShortcut());
 		ac->addAction("show_kt",show_kt_action);
 
+		setStandardToolBarMenuEnabled(true);
 				
 		QMenu* m = tray_icon->contextMenu();
 		m->addAction(start_all_action);
@@ -679,17 +680,23 @@ namespace kt
 		}
 		else
 		{
+			QTimer::singleShot(500,KApplication::kApplication(),SLOT(quit()));
 			return true;
 		}
 	}
 		
 	bool GUI::queryExit()
 	{
-		timer.stop();
-		ideal::MainWindow::queryExit();
-		hide();
-		tray_icon->hide();
-		core->onExit();
+		static bool first_time = true;
+		if (first_time)
+		{
+			timer.stop();
+			ideal::MainWindow::queryExit();
+			hide();
+			tray_icon->hide();
+			core->onExit();
+			first_time = false;
+		}
 		return true;
 	}
 
