@@ -72,8 +72,8 @@ namespace kt
 		if(arg & SYS_IPF)
 			return (arg & m_flags.SYSIPF) && ((arg & 0x0000000F) <= m_flags.SYSIPF);
 
-		if(arg & SYS_PFI)
-			return (arg & m_flags.SYSPFI) && ((arg & 0x0000000F) <= m_flags.SYSPFI);
+		if(arg & SYS_MPL)
+			return (arg & m_flags.SYSMPL) && ((arg & 0x0000000F) <= m_flags.SYSMPL);
 
 		if(arg & SYS_PNP)
 			return (arg & m_flags.SYSPNP) && ((arg & 0x0000000F) <= m_flags.SYSPNP);
@@ -87,32 +87,44 @@ namespace kt
 		if(arg & SYS_SRC)
 			return (arg & m_flags.SYSSRC) && ((arg & 0x0000000F) <= m_flags.SYSSRC);
 		
-		if(arg & SYS_RSS)
-			return (arg & m_flags.SYSRSS) && ((arg & 0x0000000F) <= m_flags.SYSRSS);
+		if(arg & SYS_BTF)
+			return (arg & m_flags.SYSBTF) && ((arg & 0x0000000F) <= m_flags.SYSBTF);
 		
 		if(arg & SYS_WEB)
 			return (arg & m_flags.SYSWEB) && ((arg & 0x0000000F) <= m_flags.SYSWEB);
 
+		if (arg & SYS_ZCO)
+			return (arg & m_flags.SYSZCO) && ((arg & 0x0000000F) <= m_flags.SYSZCO);
+
 		return true;
 	}
 
 	void LogFlags::updateFlags()
 	{
-		m_flags.SYSGEN = LogViewerPluginSettings::sysGEN();
-		m_flags.SYSCON = LogViewerPluginSettings::sysCON();
-		m_flags.SYSDHT = LogViewerPluginSettings::sysDHT();
-		m_flags.SYSTRK = LogViewerPluginSettings::sysTRK();
-		m_flags.SYSDIO = LogViewerPluginSettings::sysDIO();
+		// Possible values in config : (due to how KConfigDialog works, so we need to convert this)
+		// 0 = All
+		// 1 = Debug
+		// 2 = Notice
+		// 3 = Important
+		// 4 = None
+		unsigned int flags[] = {LOG_ALL,LOG_DEBUG,LOG_NOTICE,LOG_IMPORTANT,LOG_NONE};
 
-		m_flags.SYSINW = LogViewerPluginSettings::sysINW();
-		m_flags.SYSIPF = LogViewerPluginSettings::sysIPF();
-		m_flags.SYSPFI = LogViewerPluginSettings::sysPFI();
-		m_flags.SYSPNP = LogViewerPluginSettings::sysPNP();
-		m_flags.SYSSCD = LogViewerPluginSettings::sysSCD();
-		m_flags.SYSSNF = LogViewerPluginSettings::sysSNF();
-		m_flags.SYSSRC = LogViewerPluginSettings::sysSRC();
-		m_flags.SYSRSS = LogViewerPluginSettings::sysRSS();
-		m_flags.SYSWEB = LogViewerPluginSettings::sysWEB();
+		m_flags.SYSGEN = flags[LogViewerPluginSettings::sysGEN()];
+		m_flags.SYSCON = flags[LogViewerPluginSettings::sysCON()];
+		m_flags.SYSDHT = flags[LogViewerPluginSettings::sysDHT()];
+		m_flags.SYSTRK = flags[LogViewerPluginSettings::sysTRK()];
+		m_flags.SYSDIO = flags[LogViewerPluginSettings::sysDIO()];
+
+		m_flags.SYSINW = flags[LogViewerPluginSettings::sysINW()];
+		m_flags.SYSIPF = flags[LogViewerPluginSettings::sysIPF()];
+		m_flags.SYSMPL = flags[LogViewerPluginSettings::sysMPL()];
+		m_flags.SYSPNP = flags[LogViewerPluginSettings::sysPNP()];
+		m_flags.SYSSCD = flags[LogViewerPluginSettings::sysSCD()];
+		m_flags.SYSSNF = flags[LogViewerPluginSettings::sysSNF()];
+		m_flags.SYSSRC = flags[LogViewerPluginSettings::sysSRC()];
+		m_flags.SYSBTF = flags[LogViewerPluginSettings::sysBTF()];
+		m_flags.SYSWEB = flags[LogViewerPluginSettings::sysWEB()];
+		m_flags.SYSZCO = flags[LogViewerPluginSettings::sysZCO()];
 		
 		m_useRichText = LogViewerPluginSettings::useRichText();
 		
@@ -144,24 +156,24 @@ namespace kt
 			return line;
 		}
 		
-		if(arg & 0x04)
+		if(arg & 0x04) // Debug
 		{
 			line.prepend("<font color=\"#646464\">");
 			line.append("</font>");
 			return line;
 		}
 		
-		if(arg & 0x02)
+		if(arg & 0x02) // Notice 
 		{
 			line.prepend("<font color=\"#000000\">");
 			line.append("</font>");
-			return line;
+			return line; 
 		}
 		
-		if(arg & 0x01)
+		if(arg & 0x01) // Important
 		{
-			line.prepend("<font color=\"#460000\">");
-			line.append("</font>");
+			line.prepend("<b>");
+			line.append("</b>");
 			return line;
 		}
 		
