@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
+ *   Copyright (C) 2005-2007 by Joris Guisson                              *
  *   joris.guisson@gmail.com                                               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #include <kgenericfactory.h>
 #include <kglobal.h>
@@ -24,14 +24,12 @@
 #include <util/log.h>
 #include <torrent/globals.h>
 #include <interfaces/guiinterface.h>
+#include <interfaces/coreinterface.h>
 #include "logviewerplugin.h"
 #include "logviewer.h"
 #include "logprefpage.h"
 #include "logflags.h"
 
-#define NAME "Log Viewer"
-#define AUTHOR "Joris Guisson"
-#define EMAIL "joris.guisson@gmail.com"
 
 using namespace bt;
 
@@ -40,9 +38,7 @@ K_EXPORT_COMPONENT_FACTORY(ktlogviewerplugin,KGenericFactory<kt::LogViewerPlugin
 namespace kt
 {
 
-	LogViewerPlugin::LogViewerPlugin(QObject* parent, const char* qt_name, const QStringList& args)
-	: Plugin(parent, qt_name, args, NAME,i18n("Log Viewer"), AUTHOR, EMAIL,
-			 i18n("Displays ktorrent logging output"),"log")
+	LogViewerPlugin::LogViewerPlugin(QObject* parent,const QStringList & ) : Plugin(parent)
 	{
 		lv = 0;
 	}
@@ -54,27 +50,31 @@ namespace kt
 
 	void LogViewerPlugin::load()
 	{
+		connect(getCore(),SIGNAL(settingsChanged()),this,SLOT(applySettings()));
 		lv = new LogViewer();
-		this->getGUI()->addToolWidget(lv,"log",i18n("Log Viewer"),GUIInterface::DOCK_BOTTOM);
-		bt::Log & lg = Globals::instance().getLog(0);
-		lg.addMonitor(lv);
-		pref = new LogPrefPage();
-		this->getGUI()->addPrefPage(pref);
+		pref = new LogPrefPage(0);
+		getGUI()->addToolWidget(lv,"utilities-log-viewer",i18n("Log Viewer"),GUIInterface::DOCK_BOTTOM);
+		getGUI()->addPrefPage(pref);
+		AddLogMonitor(lv);
+		applySettings();
 	}
 
 	void LogViewerPlugin::unload()
 	{
-		this->getGUI()->removeToolWidget(lv);
-		bt::Log & lg = Globals::instance().getLog(0);
-		lg.removeMonitor(lv);
-		delete lv;
+		disconnect(getCore(),SIGNAL(settingsChanged()),this,SLOT(applySettings()));
+		getGUI()->removeToolWidget(lv);
+		getGUI()->removePrefPage(pref);
+		RemoveLogMonitor(lv);
 		lv = 0;
-		this->getGUI()->removePrefPage(pref);
-		delete pref;
 		pref = 0;
 		LogFlags::finalize();
 	}
 	
+	void LogViewerPlugin::applySettings()
+	{
+		LogFlags::instance().updateFlags();
+	}
+
 	bool LogViewerPlugin::versionCheck(const QString & version) const
 	{
 		return version == KT_VERSION_MACRO;
